audtorch.samplers
=================

.. automodule:: audtorch.samplers

BucketSampler
-----------------------------

.. autoclass:: BucketSampler
    :members:

buckets_by_boundaries
---------------------------

.. autofunction:: buckets_by_boundaries

buckets_of_even_size
------------------------------

.. autofunction:: buckets_of_even_size
